==> jc-1.4.0.tar.gz: gnu/java/nio/InputStreamChannel.h <==
// public final class gnu.java.nio.InputStreamChannel

// class file dependencies
// @dep_class 656a2344df5b8607 gnu_java_nio_InputStreamChannel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_InputStreamChannel_H_
#define _JC_gnu_java_nio_InputStreamChannel_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_gnu_java_nio_InputStreamChannel$sub_refs	_jc_gnu_java_nio_InputStreamChannel$sub_refs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs	_jc_gnu_java_nio_InputStreamChannel$sub_nonrefs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$refs	_jc_gnu_java_nio_InputStreamChannel$refs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$nonrefs	_jc_gnu_java_nio_InputStreamChannel$nonrefs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$object	_jc_gnu_java_nio_InputStreamChannel$object;

typedef const struct _jc_gnu_java_nio_InputStreamChannel$vmethods	_jc_gnu_java_nio_InputStreamChannel$vmethods;
typedef const struct _jc_gnu_java_nio_InputStreamChannel$vtable	_jc_gnu_java_nio_InputStreamChannel$vtable;
typedef const struct _jc_gnu_java_nio_InputStreamChannel$vtype	_jc_gnu_java_nio_InputStreamChannel$vtype;

// Constructors
extern void _jc_gnu_java_nio_InputStreamChannel$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_gnu_java_nio_InputStreamChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);
extern jboolean _jc_gnu_java_nio_InputStreamChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);
extern jint _jc_gnu_java_nio_InputStreamChannel$method$read$8606b3dd4fae9d79(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *);
extern void _jc_gnu_java_nio_InputStreamChannel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$isOpen$ac3c28a31bf5ea5b;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$read$8606b3dd4fae9d79;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_nio_InputStreamChannel$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);
	jint	(*read$8606b3dd4fae9d79)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *);
};

// Vtable
struct _jc_gnu_java_nio_InputStreamChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_InputStreamChannel$vmethods	gnu_java_nio_InputStreamChannel;
};

// Vtype
struct _jc_gnu_java_nio_InputStreamChannel$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_InputStreamChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_InputStreamChannel$sub_refs {
	struct _jc_java_io_InputStream$object	*in;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_InputStreamChannel$refs {
    _jc_gnu_java_nio_InputStreamChannel$sub_refs	gnu_java_nio_InputStreamChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_InputStreamChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs	gnu_java_nio_InputStreamChannel;
};

// Object instance structure
struct _jc_gnu_java_nio_InputStreamChannel$object {
	_jc_gnu_java_nio_InputStreamChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_InputStreamChannel$vtype	*vtype;
	_jc_gnu_java_nio_InputStreamChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_InputStreamChannel$vtype _jc_gnu_java_nio_InputStreamChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_InputStreamChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_InputStreamChannel$class_object;

#endif	/* _JC_gnu_java_nio_InputStreamChannel_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/InputStreamChannel.h <==
// public final class gnu.java.nio.InputStreamChannel

// class file dependencies
// @dep_class 656a2344df5b8607 gnu_java_nio_InputStreamChannel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_InputStreamChannel_H_
#define _JC_gnu_java_nio_InputStreamChannel_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_gnu_java_nio_InputStreamChannel$sub_refs	_jc_gnu_java_nio_InputStreamChannel$sub_refs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs	_jc_gnu_java_nio_InputStreamChannel$sub_nonrefs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$refs	_jc_gnu_java_nio_InputStreamChannel$refs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$nonrefs	_jc_gnu_java_nio_InputStreamChannel$nonrefs;
typedef struct _jc_gnu_java_nio_InputStreamChannel$object	_jc_gnu_java_nio_InputStreamChannel$object;

typedef const struct _jc_gnu_java_nio_InputStreamChannel$vmethods	_jc_gnu_java_nio_InputStreamChannel$vmethods;
typedef const struct _jc_gnu_java_nio_InputStreamChannel$vtable	_jc_gnu_java_nio_InputStreamChannel$vtable;
typedef const struct _jc_gnu_java_nio_InputStreamChannel$vtype	_jc_gnu_java_nio_InputStreamChannel$vtype;

// Constructors
extern void _jc_gnu_java_nio_InputStreamChannel$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_InputStreamChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_nio_InputStreamChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_InputStreamChannel$method$read$8606b3dd4fae9d79(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_InputStreamChannel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$isOpen$ac3c28a31bf5ea5b;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$read$8606b3dd4fae9d79;
extern _jc_method _jc_gnu_java_nio_InputStreamChannel$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_nio_InputStreamChannel$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;
	jint	(*read$8606b3dd4fae9d79)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_nio_InputStreamChannel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_InputStreamChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_InputStreamChannel$vmethods	gnu_java_nio_InputStreamChannel;
};

// Vtype
struct _jc_gnu_java_nio_InputStreamChannel$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_InputStreamChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_InputStreamChannel$sub_refs {
	struct _jc_java_io_InputStream$object	*in;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_InputStreamChannel$refs {
    _jc_gnu_java_nio_InputStreamChannel$sub_refs	gnu_java_nio_InputStreamChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_InputStreamChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_InputStreamChannel$sub_nonrefs	gnu_java_nio_InputStreamChannel;
};

// Object instance structure
struct _jc_gnu_java_nio_InputStreamChannel$object {
	_jc_gnu_java_nio_InputStreamChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_InputStreamChannel$vtype	*vtype;
	_jc_gnu_java_nio_InputStreamChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_InputStreamChannel$vtype _jc_gnu_java_nio_InputStreamChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_InputStreamChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_InputStreamChannel$class_object;

#endif	/* _JC_gnu_java_nio_InputStreamChannel_H_ */
